<?php


namespace Drupal\other\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\other\Traits\LightCategoryTrait;

/**
 * Provides a 'Light Category Block'.
 * 
 * @Block(
 * id = "light_category_block",
 * admin_label = @Translation("Light Category Block"),
 * category = @Translation("Views"),
 * )
 */



 class LightCategoryBlock extends BlockBase implements BlockPluginInterface {

    use LightCategoryTrait;


    /**
     * {@inheritdoc}
     */

     public function blockForm($form, FormStateInterface $form_state)
     {
        
        $form = parent::blockForm($form, $form_state);
        $config = $this->getConfiguration();

        $form['light-category-wrapper'] = [
          '#prefix' => '<div class="light-category-wrapper">',
          '#suffix' => '</div>',
        ];
        $form['arguments'] = array(
         '#type' => 'entity_autocomplete',
         '#target_type' => 'taxonomy_term',
         '#title' => $this->t('View arguments'),
         '#description' =>   $this->t('Select the terms you want to set as a contextual filter for the view.'),
         '#default_value' => !empty($config['arguments']) ? \Drupal::entityTypeManager()->getStorage('taxonomy_term')->load($config['arguments']) : '',
         '#autocreate' => FALSE,
         '#required' => TRUE,
         '#tag' => FALSE,
       );


       $form['view'] = [
        '#type' => 'select',
        '#title' => $this->t('Select a view display'),
        '#description' => $this->t('Only view block'),
        '#options' =>LightCategoryTrait::getViewSelect(),
        '#default_value' => !empty($config['view']) ? $config['view'] : NULL,
        '#empty_option' => '- Select -',
        '#required' => TRUE
       ];

         return $form;
     }
    /**
     * {@inheritdoc}
     */

    /**
     * {@inheritdoc}
     */
    public function blockSubmit($form, FormStateInterface $form_state) {
      parent::blockSubmit($form, $form_state);
      $values = $form_state->getValues();
      $this->configuration['arguments'] = $values['arguments'];
      $this->configuration['view'] = $values['view'];
    }



    public function build()
    {
      $viewKey = $this->configuration['view'];
      $args = $this->configuration['arguments'];
      $view =\Drupal\views\Views::getView( $viewKey );
      $view->setDisplay('block_1');
      $displayObj = $view->getDisplay();
      $displayObj->view->setArguments( [ $args] );
      $displayObj->preExecute();
      $displayObj->execute();
      return  $displayObj->buildRenderable();
     }


 }